@@ -9,6 +9,11 @@ li = list(
 )
 
 test_that("checkAtomic", {
+  myobj = 1:2
+  expect_succ(Atomic, myobj)
+  myobj = iris
+  expect_fail(Atomic, myobj)
+
   expect_true(testAtomic(integer(0)))
   expect_true(testAtomic(NULL))
   expect_true(testAtomic(1))
@@ -40,7 +45,6 @@ test_that("checkAtomic", {
   expect_true(testAtomic(setNames(1, "x"), names="named"))
   expect_false(testAtomic(1, names="unique"))
 
-  expect_true(assertAtomic(1))
   expect_error(assertAtomic(iris), "atomic")
 
   expect_equal(sapply(li, is.atomic), sapply(li, testAtomic))
